;; $Id: sd_browser_views.lsp 7 2005-11-20 19:03:43Z pjahn $
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Description:  SolidDesigner's default "Browser Views" file
;
; (C) Copyright 1997-2005 CoCreate Software GmbH & Co. KG, all rights reserved.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; This file contains definitions of browser views that can be activated
;; via the structure browser "Views" menu button.
;;
;; A browser view can be specified as follows:
;;
;;  (oli:sd-create-browser-view
;;     {STRING}
;;        Unique browser view name
;;     :title {STRING}
;;        Browser view title that will be displayed in the
;;        browser views menu.
;;        If not given, the browser view name will be displayed.
;;     :tree-config {LIST|STRING}
;;        List containing column keywords and padding strings.
;;        The value of the specified columns and the padding strings are
;;        concatenated together to form the text that will be displayed
;;        at each browser node in the browser tree. If a string is passed
;;        then this should identify an existing configuration. See
;;        sd-create-browser-configuration for details.
;;     :detail-config {LIST|STRING}
;;        List containing column keywords. Specified columns appear
;;        when detail mode of browser is switched on. If a string is passed
;;        then this should identify an existing configuration. See
;;        sd-create-browser-configuration for details.
;;     :activate-detail-configuration [t|nil]
;;        If set to t this parameter ensures that the detail part of the
;;        browser is displayed otherwise the view shows tree only when
;;        activated. Default is t.
;;     :enable {LISP expression}
;;        The browser view will be included in the browser view menu
;;        if this LISP expression evaluates to a NON-NIL value.
;;        If not given, the browser view will be accessible in the browser
;;        view menu without restrictions.
;;
;; This file contains browser configurations which can be called from multiple
;; browser views.
;;
;; sd-create-browser-configuration
;;     {STRING}
;;        Unique browser configuration name
;;     :config {LIST}
;;        List containing column keywords and padding strings.
;;        The value of the specified columns and the padding strings are
;;        concatenated together to form the text that will be displayed
;;        at each browser node in the browser tree. Once created this
;;        browser configuration can be used with sd-create-browser-view
;;        either as a table or a tree configuration. If it is used as a
;;        table configuration then the padding string will be ignored.

(oli:sd-create-browser-view
  "DEFAULT"
  :tree-config '(:instance-name)
  :detail-config '(:contents-name :db-state :shared :selective-instance-context)
  :title "Standard"
:derive-virtual-title-from-child t
  :enable '(and (not (oli:sd-license-free-module-active-p "ModelManager"))
                (not (oli:sd-license-free-module-active-p "PEWMSD")))
)

(oli:sd-set-default-browser-view "SolidDesigner" "DEFAULT")

(oli::sd-browser-exec-cmd "parcel-gbrowser"
  :set-browser-mode-order
  '( :container-mode
     :configuration-mode
     :clash_analysis-mode
     :rel_set-mode
     :animation-mode
     :simplification
     :molddesignadv
     :taper-feature
     :sheet-metal
     :3d-library
     :study-mode
     :manufacturing
     :gdt-dims
     :gdt-symbols
     :gdt
     :3d-annotation
     :group-mode
     :grouping-features
     :open-reference
     :element-names
     :generic-texts
     :hidden-features
     :user-defined-feature
     :feature-mode
     :coord_sys-mode
     :docu_plane-mode
     :layout-mode
     :others-mode)
)
